"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.loadCommonJsModule = exports.createCommonJsModuleLoader = void 0;
const node_fetch_1 = __importDefault(require("node-fetch"));
/**
 * @param externals An object with shared npm dependencies that the integrator
 * wants to provide to Feature Apps. The keys are the names of the dependencies
 * that are used in import/require statements. The values are the modules.
 *
 * @param requestInit An object containing any custom settings that should be
 * applied to the request when fetching a module with node-fetch.
 *
 * @returns A function that accepts a URL pointing to a bundle that was built as
 * a CommonJS module, and that returns a promise that resolves with the loaded
 * module, or is rejected if the module can not be loaded.
 */
function createCommonJsModuleLoader(externals = {}, requestInit) {
    return async (url) => {
        const response = await (0, node_fetch_1.default)(url, requestInit);
        const source = await response.text();
        const mod = { exports: {} };
        // tslint:disable-next-line:function-constructor
        Function('module', 'exports', 'require', `${source}
      //# sourceURL=${url}`)(mod, mod.exports, (dep) => 
        // tslint:disable-next-line:no-eval https://stackoverflow.com/a/41063795/10385541
        externals.hasOwnProperty(dep) ? externals[dep] : eval('require')(dep));
        return mod.exports;
    };
}
exports.createCommonJsModuleLoader = createCommonJsModuleLoader;
/**
 * @param url A URL pointing to a bundle that was built as a CommonJS module.
 *
 * @returns A promise that resolves with the loaded module, or is rejected if
 * the module can not be loaded.
 */
exports.loadCommonJsModule = createCommonJsModuleLoader();
//# sourceMappingURL=index.js.map